==> sgmarkets_api_auth-0.2.1.tar.gz: sgmarkets_api_auth-0.2.1/README.md <==
# SG Markets API Authentication

## 1- Introduction

This repo is a helper package for clients (and employees) to autheticate with SG Markets APIs.  


## 2 - Install

From terminal:
```bash
# download and install package from pypi.org
pip install sgmarkets_api_auth
```


## 3 - User guide

### 3.1 - Define you credentials

Create a file `my_secret.txt` (or pick the name) in your home directory.  
+ On Windows: `C:\Users\youraccountsname`.
+ On Linux/macOS: `~/youraccountsname`.
+ In a [mybinder.org](mybinder.org) context the JupyterHub home directory

This file must contain your secrets in the following format:
```bash
# not compulsory in interactive mode
SG_LOGIN=myownsglogin
SG_PASSWORD=myownsgpwd

# compulsory even as blank
PROXY_LOGIN=myownproxylogin
PROXY_PASSWORD=myownproxypwd

# compulsory even as blank
PROXY_HOST=myownproxyhost
PROXY_PORT=myownproxyport
```

Pass this file name as argument to the Api object.

```python
from sgmarkets_api_auth import Api
# default name is 'my_secret.txt'
a = Api()

# default name is 'my_secret.txt'
a = Api(path_secret='my_custom_secret.txt')

# to see the logs - default is False
a = Api(verbose=True)

# to force update token - default is False
a = Api(update_token=True)

# interactive mode
# to request password and optionally login through form
# (login prefilled if SG_LOGIN defined in my_secret.txt)
# default is False
a = Api(interactive=True)

# to remove secrets and token from disk
a.clear_secret_token()
```

See the [demo notebook](http://nbviewer.jupyter.org/urls/gitlab.com/sgmarkets/sgmarkets-api-auth/raw/master/demo_sgmarkets_api_auth.ipynb).

### 3.2 - Make an API call

Read the demo notebooks for various APIs in the same gitlab [sgmarkets organization](https://gitlab.com/sgmarkets).  
There you can see how to use the `Api` object to make a request to an SG Markets API and analyse the response.  

### 3.3 - Utility: pickle/unpickle

It is sometimes convenient to store an API response object on disk, particularly if the API request is long.  
In order to do so this package contains a pickle/unpickle utility functions.  



```python
from sgmarkets_api_auth.util import topickle, unpickle

path = os.path.join('path', 'to', 'filename.pk')

# to store obj - a response object for example
# compresslevel is 4 by default on a scale from 0 to 9
topickle(path, obj, compresslevel=1)

# to retrieve obj
obj2 = unpickle(path)
```

==> sgmarkets_api_auth-0.3.0.tar.gz: sgmarkets_api_auth-0.3.0/README.md <==
# SG Markets API Authentication


> This package had a major update on 22apr20.  
    Run `pip install -U sgmarkets_api_auth` to update.

## 1- Introduction

This repo is a helper package for clients (and employees) to autheticate with SG Markets APIs.  


## 2 - Install

From terminal:
```bash
# download and install package from pypi.org
pip install sgmarkets_api_auth
```


## 3 - User guide

### 3.1 - Define you credentials

Create a file `my-secret.txt` (or pick the name) in your home directory.  
+ On Windows: `C:\Users\youraccountsname`.
+ On Linux/macOS: `~/youraccountsname`.

This file must contain your secrets in the following format:
```bash
SG_TOKEN=myowntoken

# compulsory even as blank
PROXY_LOGIN=myownproxylogin
PROXY_PASSWORD=myownproxypwd

# compulsory even as blank
PROXY_HOST=myownproxyhost
PROXY_PORT=myownproxyport
```

Pass this file name as argument to the Api object.

```python
from sgmarkets_api_auth import Api
# default name is 'my-secret.txt'
a = Api()

# default name is 'my-secret.txt'
a = Api(path_secret='my_custom_secret.txt')

# to see the logs - default is False
a = Api(verbose=True)

# to remove secrets and token from disk
a.clear_secret_token()
```

See the [demo notebook](http://nbviewer.jupyter.org/urls/gitlab.com/sgmarkets/sgmarkets-api-auth/raw/master/demo_sgmarkets_api_auth.ipynb).

### 3.2 - Make an API call

Read the demo notebooks for various APIs in the same gitlab [sgmarkets organization](https://gitlab.com/sgmarkets).  
There you can see how to use the `Api` object to make a request to an SG Markets API and analyse the response.
